@@ -63,11 +63,13 @@ static int _is_small_prime7(UV n)
 
 static UV next_small_prime(UV n)
 {
+  UV d, m;
+
   if (n < 7)
     return (n < 2) ? 2 : (n < 3) ? 3 : (n < 5) ? 5 : 7;
 
-  UV d = n/30;
-  UV m = n - d*30;
+  d = n/30;
+  m = n - d*30;
   /* Move forward one, knowing we may not be on the wheel */
   if (m == 29) { d++; m = 1; } else  { m = next_wheel[m]; }
   while (!_is_small_prime7(d*30+m)) {
@@ -78,11 +80,13 @@ static UV next_small_prime(UV n)
 
 static UV prev_small_prime(UV n)
 {
+  UV d, m;
+
   if (n <= 7)
     return (n <= 2) ? 0 : (n <= 3) ? 2 : (n <= 5) ? 3 : 5;
 
-  UV d = n/30;
-  UV m = n - d*30;
+  d = n/30;
+  m = n - d*30;
   do {
     m = prev_wheel[m];
     if (m == 29) { d--; }
@@ -352,7 +356,7 @@ void _GMP_next_prime(mpz_t n)
 
   mpz_init(d);
   m = mpz_fdiv_q_ui(d, n, 30);
-  
+
   if (m == 29) {
     mpz_add_ui(d, d, 1);
     m = 1;
@@ -385,7 +389,7 @@ void _GMP_prev_prime(mpz_t n)
 
   mpz_init(d);
   m = mpz_fdiv_q_ui(d, n, 30);
-  
+
   while (1) {
     m = prev_wheel[m];
     if (m == 29)
@@ -502,13 +506,15 @@ int _GMP_pbrent_factor(mpz_t n, mpz_t f, UV a, UV rounds)
 }
 
 
-static void lcm_to_B(UV B, mpz_t m)
+void _GMP_lcm_of_consecutive_integers(UV B, mpz_t m)
 {
   double logB = log(B);
   UV p, exponent;
 
   /* Simple sieve to B */
   unsigned char* s = sieve_erat(B);
+  if (s == 0)
+    croak("Could not get sieve for primes up to %lu\n", (unsigned long) B);
 
   mpz_set_ui(m, 1);
   exponent = logB / log(2);
@@ -535,6 +541,8 @@ static void calculate_b_lcm(mpz_t b, UV B, mpz_t a, mpz_t n)
 
   /* Simple sieve to B */
   unsigned char* s = sieve_erat(B);
+  if (s == 0)
+    croak("Could not get sieve for primes up to %lu\n", (unsigned long) B);
 
   mpz_init(m);
   mpz_set(b, a);
@@ -572,7 +580,7 @@ int _GMP_pminus1_factor(mpz_t n, mpz_t f, UV smoothness_bound)
   B = 5;
   while (B <= smoothness_bound) {
     if (verbose) gmp_printf("   calculating new m for B=%lu...\n", (unsigned long)B);
-    lcm_to_B(B, m);
+    _GMP_lcm_of_consecutive_integers(B, m);
     if (verbose) gmp_printf("trying %Zd  with B=%lu", n, (unsigned long)B); if (B<100) gmp_printf(" m=%Zd", m); gmp_printf("\n");
     /* Use primes for a's to try.  We rarely make it past the first couple. */
     p = 1;
@@ -649,13 +657,13 @@ int _GMP_pminus1_factor(mpz_t n, mpz_t f, UV B1, UV B2)
   mpz_init(x);
   mpz_init(b);
 
-  if (_verbose>1) gmp_printf("trying %Zd  with B=%lu\n", n, (unsigned long)B1);
+  if (_verbose>1) gmp_printf("# trying %Zd  with B=%lu\n", n, (unsigned long)B1);
   /* Use primes for a's to try.  We rarely make it past the first couple. */
   p = 1;
   while ( (p = next_small_prime(p)) < 100 ) {
-    if (_verbose && p > 2) gmp_printf("trying with a=%d\n", (int)p);
+    if (_verbose && p > 2) gmp_printf("#   again with a=%d\n", (int)p);
     mpz_set_ui(a, p);
-    if (_verbose>1) gmp_printf("   calculating new b(%Zd) for B=%lu...\n", a, (unsigned long)B1);
+    if (_verbose>1) gmp_printf("#   calculating new b(%Zd) for B=%lu...\n", a, (unsigned long)B1);
     calculate_b_lcm(b, B1, a, n);
     mpz_set(x, b);
     if (mpz_sgn(x) == 0) mpz_set(x, n);
@@ -675,7 +683,7 @@ int _GMP_pminus1_factor(mpz_t n, mpz_t f, UV B1, UV B2)
    */
   if (B2 > B1) {
     UV q;
-    if (_verbose>1) gmp_printf("Starting second stage from %lu to %lu\n", (unsigned long)B1, (unsigned long)B2);
+    if (_verbose>1) gmp_printf("# Starting second stage from %lu to %lu\n", (unsigned long)B1, (unsigned long)B2);
     p = prev_small_prime(B1);
     q = p;
     /* TODO: segmented sieve to get q's is probably a lot faster */
@@ -686,13 +694,13 @@ int _GMP_pminus1_factor(mpz_t n, mpz_t f, UV B1, UV B2)
       mpz_sub_ui(x, x, 1);
       mpz_gcd(f, x, n);
       if ( (mpz_cmp_ui(f, 1) != 0) && (mpz_cmp(f, n) != 0) ) {
-        if (_verbose>1) gmp_printf("p-1 second stage found factor %Zd\n", f);
+        if (_verbose>1) gmp_printf("# p-1 second stage found factor %Zd\n", f);
         mpz_clear(a); mpz_clear(m); mpz_clear(x); mpz_clear(b);
         return 1;
       }
       p = q;
     }
-    if (_verbose>1) gmp_printf("End second stage\n");
+    if (_verbose>1) gmp_printf("# End second stage\n");
   }
 
   mpz_clear(a); mpz_clear(m); mpz_clear(x); mpz_clear(b);
@@ -794,11 +802,13 @@ int _GMP_holf_factor(mpz_t n, mpz_t f, UV rounds)
 
 static int shanks_mult(mpz_t n, mpz_t f)
 {
-   // use shanks SQUFOF to factor N.
-   //
-   // return 0 if no factor found, 1 if found with factor in f1.
-   //
-   // Input should have gone through trial division to 5.
+   /*
+    * use shanks SQUFOF to factor N.
+    *
+    * return 0 if no factor found, 1 if found with factor in f1.
+    *
+    * Input should have gone through trial division to 5.
+    */
 
    int result = 0;
    unsigned long j=0;
@@ -831,7 +841,7 @@ static int shanks_mult(mpz_t n, mpz_t f)
    mpz_sqrt(tmp, b0);
    mpz_mul_ui(imax, tmp, 3);
 
-   //set up recurrence
+   /* set up recurrence */
    mpz_set_ui(Q0, 1);
    mpz_set(P, b0);
    mpz_mul(tmp, b0, b0);
@@ -844,18 +854,18 @@ static int shanks_mult(mpz_t n, mpz_t f)
    while (1) {
       j=0;
       while (1) {
-         mpz_set(t1, P);  //hold Pn for this iteration
+         mpz_set(t1, P);   /* hold Pn for this iteration */
          mpz_mul(tmp, bn, Qn);
          mpz_sub(P, tmp, P);
-         mpz_set(t2, Qn);  //hold Qn for this iteration
+         mpz_set(t2, Qn);  /* hold Qn for this iteration */
          mpz_sub(tmp, t1, P);
          mpz_mul(tmp, tmp, bn);
          mpz_add(Qn, Q0, tmp);
-         mpz_set(Q0, t2);  //remember last Q
+         mpz_set(Q0, t2);  /* remember last Q */
          mpz_add(tmp, b0, P);
          mpz_tdiv_q(bn, tmp, Qn);
 
-         if (mpz_even_p(i)) {   // i even
+         if (mpz_even_p(i)) {
            if (mpz_perfect_square_p(Qn)) {
              mpz_add_ui(i, i, 1);
              break;
@@ -869,45 +879,43 @@ static int shanks_mult(mpz_t n, mpz_t f)
          }
       }
 
-      //reduce to G0
+      /* reduce to G0 */
       mpz_sqrt(S, Qn);
       mpz_sub(tmp, b0, P);
       mpz_tdiv_q(tmp, tmp, S);
       mpz_mul(tmp, S, tmp);
       mpz_add(Ro, P, tmp);
-      //mpz_set(t1, Ro);
-      //mpz_mul(tmp, t1, t1);
       mpz_mul(tmp, Ro, Ro);
       mpz_sub(tmp, n, tmp);
       mpz_tdiv_q(So, tmp, S);
       mpz_add(tmp, b0, Ro);
       mpz_tdiv_q(bbn, tmp, So);
 
-      //search for symmetry point
+      /* search for symmetry point */
       while (1) {
-         mpz_set(t1, Ro);  //hold Ro for this iteration
+         mpz_set(t1, Ro);  /* hold Ro for this iteration */
          mpz_mul(tmp, bbn, So);
          mpz_sub(Ro, tmp, Ro);
-         mpz_set(t2, So);  //hold So for this iteration
+         mpz_set(t2, So);  /* hold So for this iteration */
          mpz_sub(tmp, t1, Ro);
          mpz_mul(tmp, bbn, tmp);
          mpz_add(So, S, tmp);
-         mpz_set(S, t2);   //remember last S
+         mpz_set(S, t2);   /* remember last S */
          mpz_add(tmp, b0, Ro);
          mpz_tdiv_q(bbn, tmp, So);
 
-         //check for symmetry point
+         /* check for symmetry point */
          if (mpz_cmp(Ro, t1) == 0)
             break;
 
-         //this gets stuck very rarely, but it does happen.
+         /* this gets stuck very rarely, but it does happen. */
          if (++j > 1000000000)
          {
             result = -1;
             goto end;
          }
       }
-   
+
       mpz_gcd(t1, Ro, n);
       if (mpz_cmp_ui(t1, 1) > 0) {
          mpz_set(f, t1);
@@ -937,11 +945,11 @@ static int shanks_mult(mpz_t n, mpz_t f)
 
 int _GMP_squfof_factor(mpz_t n, mpz_t f, UV rounds)
 {
-   //call shanks with multiple small multipliers
-   const int multipliers[] = {3, 5, 7, 
-            11, 3*5, 3*7, 3*11, 
-            5*7, 5*11, 7*11, 
-            3*5*7, 3*5*11, 3*7*11, 
+   /* call shanks with multiple small multipliers */
+   const int multipliers[] = {3, 5, 7,
+            11, 3*5, 3*7, 3*11,
+            5*7, 5*11, 7*11,
+            3*5*7, 3*5*11, 3*7*11,
             5*7*11, 3*5*7*11, 1};
 
    const int sz_mul = 16;
